import typing

import typing_extensions

_list = list

@typing.type_check_only
class CustomResourceColumnDefinition(typing_extensions.TypedDict, total=False):
    description: str
    format: str
    jsonPath: str
    name: str
    priority: int
    type: str

@typing.type_check_only
class CustomResourceDefinition(typing_extensions.TypedDict, total=False):
    apiVersion: str
    kind: str
    metadata: ObjectMeta
    spec: CustomResourceDefinitionSpec

@typing.type_check_only
class CustomResourceDefinitionNames(typing_extensions.TypedDict, total=False):
    categories: _list[str]
    kind: str
    listKind: str
    plural: str
    shortNames: _list[str]
    singular: str

@typing.type_check_only
class CustomResourceDefinitionSpec(typing_extensions.TypedDict, total=False):
    additionalPrinterColumns: _list[CustomResourceColumnDefinition]
    group: str
    names: CustomResourceDefinitionNames
    scope: str
    subresources: CustomResourceSubresources
    validation: CustomResourceValidation
    version: str
    versions: _list[CustomResourceDefinitionVersion]

@typing.type_check_only
class CustomResourceDefinitionVersion(typing_extensions.TypedDict, total=False):
    name: str
    served: bool
    storage: bool

@typing.type_check_only
class CustomResourceSubresourceScale(typing_extensions.TypedDict, total=False):
    labelSelectorPath: str
    specReplicasPath: str
    statusReplicasPath: str

@typing.type_check_only
class CustomResourceSubresourceStatus(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class CustomResourceSubresources(typing_extensions.TypedDict, total=False):
    scale: CustomResourceSubresourceScale
    status: CustomResourceSubresourceStatus

@typing.type_check_only
class CustomResourceValidation(typing_extensions.TypedDict, total=False):
    openAPIV3Schema: JSONSchemaProps

@typing.type_check_only
class ExternalDocumentation(typing_extensions.TypedDict, total=False):
    description: str
    url: str

@typing.type_check_only
class JSON(typing_extensions.TypedDict, total=False):
    raw: str

AlternativeJSONSchemaProps = typing_extensions.TypedDict(
    "AlternativeJSONSchemaProps",
    {
        "additionalItems": JSONSchemaPropsOrBool,
        "additionalProperties": JSONSchemaPropsOrBool,
        "allOf": _list[JSONSchemaProps],
        "anyOf": _list[JSONSchemaProps],
        "default": JSON,
        "definitions": dict[str, typing.Any],
        "dependencies": dict[str, typing.Any],
        "description": str,
        "enum": _list[str],
        "example": JSON,
        "exclusiveMaximum": bool,
        "exclusiveMinimum": bool,
        "externalDocs": ExternalDocumentation,
        "format": str,
        "id": str,
        "items": JSONSchemaPropsOrArray,
        "maxItems": str,
        "maxLength": str,
        "maxProperties": str,
        "maximum": float,
        "minItems": str,
        "minLength": str,
        "minProperties": str,
        "minimum": float,
        "multipleOf": float,
        "not": JSONSchemaProps,
        "oneOf": _list[JSONSchemaProps],
        "pattern": str,
        "patternProperties": dict[str, typing.Any],
        "properties": dict[str, typing.Any],
        "ref": str,
        "required": _list[str],
        "schema": str,
        "title": str,
        "type": str,
        "uniqueItems": bool,
    },
    total=False,
)

@typing.type_check_only
class JSONSchemaProps(AlternativeJSONSchemaProps): ...

@typing.type_check_only
class JSONSchemaPropsOrArray(typing_extensions.TypedDict, total=False):
    jsonSchemas: _list[JSONSchemaProps]
    schema: JSONSchemaProps

@typing.type_check_only
class JSONSchemaPropsOrBool(typing_extensions.TypedDict, total=False):
    allows: bool
    schema: JSONSchemaProps

@typing.type_check_only
class JSONSchemaPropsOrStringArray(typing_extensions.TypedDict, total=False):
    property: _list[str]
    schema: JSONSchemaProps

@typing.type_check_only
class ListCustomResourceDefinitionsResponse(typing_extensions.TypedDict, total=False):
    apiVersion: str
    items: _list[CustomResourceDefinition]
    kind: str
    metadata: ListMeta
    unreachable: _list[str]

AlternativeListMeta = typing_extensions.TypedDict(
    "AlternativeListMeta",
    {
        "continue": str,
        "resourceVersion": str,
        "selfLink": str,
    },
    total=False,
)

@typing.type_check_only
class ListMeta(AlternativeListMeta): ...

@typing.type_check_only
class ObjectMeta(typing_extensions.TypedDict, total=False):
    annotations: dict[str, typing.Any]
    clusterName: str
    creationTimestamp: str
    deletionGracePeriodSeconds: int
    deletionTimestamp: str
    finalizers: _list[str]
    generateName: str
    generation: int
    labels: dict[str, typing.Any]
    name: str
    namespace: str
    ownerReferences: _list[OwnerReference]
    resourceVersion: str
    selfLink: str
    uid: str

@typing.type_check_only
class OwnerReference(typing_extensions.TypedDict, total=False):
    apiVersion: str
    blockOwnerDeletion: bool
    controller: bool
    kind: str
    name: str
    uid: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CloudRunResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class JobsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class ExecutionsResource(googleapiclient.discovery.Resource):
                    @typing.type_check_only
                    class TasksResource(googleapiclient.discovery.Resource):
                        def get(
                            self, *, name: str, **kwargs: typing.Any
                        ) -> GoogleCloudRunV2TaskHttpRequest: ...
                        def list(
                            self,
                            *,
                            parent: str,
                            pageSize: int = ...,
                            pageToken: str = ...,
                            showDeleted: bool = ...,
                            **kwargs: typing.Any
                        ) -> GoogleCloudRunV2ListTasksResponseHttpRequest: ...
                        def list_next(
                            self,
                            previous_request: GoogleCloudRunV2ListTasksResponseHttpRequest,
                            previous_response: GoogleCloudRunV2ListTasksResponse,
                        ) -> GoogleCloudRunV2ListTasksResponseHttpRequest | None: ...

                    def delete(
                        self,
                        *,
                        name: str,
                        etag: str = ...,
                        validateOnly: bool = ...,
                        **kwargs: typing.Any
                    ) -> GoogleLongrunningOperationHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> GoogleCloudRunV2ExecutionHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        showDeleted: bool = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudRunV2ListExecutionsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: GoogleCloudRunV2ListExecutionsResponseHttpRequest,
                        previous_response: GoogleCloudRunV2ListExecutionsResponse,
                    ) -> GoogleCloudRunV2ListExecutionsResponseHttpRequest | None: ...
                    def tasks(self) -> TasksResource: ...

                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudRunV2Job = ...,
                    jobId: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def delete(
                    self,
                    *,
                    name: str,
                    etag: str = ...,
                    force: bool = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudRunV2JobHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    showDeleted: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudRunV2ListJobsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudRunV2ListJobsResponseHttpRequest,
                    previous_response: GoogleCloudRunV2ListJobsResponse,
                ) -> GoogleCloudRunV2ListJobsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudRunV2Job = ...,
                    allowMissing: bool = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def run(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudRunV2RunJobRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1TestIamPermissionsResponseHttpRequest: ...
                def executions(self) -> ExecutionsResource: ...

            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def list(
                    self,
                    *,
                    name: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningListOperationsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleLongrunningListOperationsResponseHttpRequest,
                    previous_response: GoogleLongrunningListOperationsResponse,
                ) -> GoogleLongrunningListOperationsResponseHttpRequest | None: ...

            @typing.type_check_only
            class ServicesResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class RevisionsResource(googleapiclient.discovery.Resource):
                    def delete(
                        self,
                        *,
                        name: str,
                        etag: str = ...,
                        validateOnly: bool = ...,
                        **kwargs: typing.Any
                    ) -> GoogleLongrunningOperationHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> GoogleCloudRunV2RevisionHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        showDeleted: bool = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudRunV2ListRevisionsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: GoogleCloudRunV2ListRevisionsResponseHttpRequest,
                        previous_response: GoogleCloudRunV2ListRevisionsResponse,
                    ) -> GoogleCloudRunV2ListRevisionsResponseHttpRequest | None: ...

                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudRunV2Service = ...,
                    serviceId: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def delete(
                    self,
                    *,
                    name: str,
                    etag: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudRunV2ServiceHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    showDeleted: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudRunV2ListServicesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudRunV2ListServicesResponseHttpRequest,
                    previous_response: GoogleCloudRunV2ListServicesResponse,
                ) -> GoogleCloudRunV2ListServicesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudRunV2Service = ...,
                    allowMissing: bool = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1TestIamPermissionsResponseHttpRequest: ...
                def revisions(self) -> RevisionsResource: ...

            def jobs(self) -> JobsResource: ...
            def operations(self) -> OperationsResource: ...
            def services(self) -> ServicesResource: ...

        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class GoogleCloudRunV2ExecutionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRunV2Execution: ...

@typing.type_check_only
class GoogleCloudRunV2JobHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRunV2Job: ...

@typing.type_check_only
class GoogleCloudRunV2ListExecutionsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRunV2ListExecutionsResponse: ...

@typing.type_check_only
class GoogleCloudRunV2ListJobsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRunV2ListJobsResponse: ...

@typing.type_check_only
class GoogleCloudRunV2ListRevisionsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRunV2ListRevisionsResponse: ...

@typing.type_check_only
class GoogleCloudRunV2ListServicesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRunV2ListServicesResponse: ...

@typing.type_check_only
class GoogleCloudRunV2ListTasksResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRunV2ListTasksResponse: ...

@typing.type_check_only
class GoogleCloudRunV2RevisionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRunV2Revision: ...

@typing.type_check_only
class GoogleCloudRunV2ServiceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRunV2Service: ...

@typing.type_check_only
class GoogleCloudRunV2TaskHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRunV2Task: ...

@typing.type_check_only
class GoogleIamV1PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleIamV1Policy: ...

@typing.type_check_only
class GoogleIamV1TestIamPermissionsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleIamV1TestIamPermissionsResponse: ...

@typing.type_check_only
class GoogleLongrunningListOperationsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunningListOperationsResponse: ...

@typing.type_check_only
class GoogleLongrunningOperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunningOperation: ...

@typing.type_check_only
class GoogleProtobufEmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleProtobufEmpty: ...



from _typeshed import Incomplete

HAS_GOOGLE_AUTH: bool
HAS_OAUTH2CLIENT: bool

def credentials_from_file(
    filename, scopes: Incomplete | None = ..., quota_project_id: Incomplete | None = ...
): ...
def default_credentials(
    scopes: Incomplete | None = ..., quota_project_id: Incomplete | None = ...
): ...
def with_scopes(credentials, scopes): ...
def authorized_http(credentials): ...
def refresh_credentials(credentials): ...
def apply_credentials(credentials, headers): ...
def is_valid(credentials): ...
def get_credentials_from_http(http): ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AddFirebaseRequest(typing_extensions.TypedDict, total=False):
    locationId: str

@typing.type_check_only
class AddGoogleAnalyticsRequest(typing_extensions.TypedDict, total=False):
    analyticsAccountId: str
    analyticsPropertyId: str

@typing.type_check_only
class AdminSdkConfig(typing_extensions.TypedDict, total=False):
    databaseURL: str
    locationId: str
    projectId: str
    storageBucket: str

@typing.type_check_only
class AnalyticsDetails(typing_extensions.TypedDict, total=False):
    analyticsProperty: AnalyticsProperty
    streamMappings: _list[StreamMapping]

@typing.type_check_only
class AnalyticsProperty(typing_extensions.TypedDict, total=False):
    analyticsAccountId: str
    displayName: str
    id: str

@typing.type_check_only
class AndroidApp(typing_extensions.TypedDict, total=False):
    apiKeyId: str
    appId: str
    displayName: str
    name: str
    packageName: str
    projectId: str
    sha1Hashes: _list[str]
    sha256Hashes: _list[str]
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "ACTIVE", "DELETED"]

@typing.type_check_only
class AndroidAppConfig(typing_extensions.TypedDict, total=False):
    configFileContents: str
    configFilename: str

@typing.type_check_only
class DefaultResources(typing_extensions.TypedDict, total=False):
    hostingSite: str
    locationId: str
    realtimeDatabaseInstance: str
    storageBucket: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class FinalizeDefaultLocationRequest(typing_extensions.TypedDict, total=False):
    locationId: str

@typing.type_check_only
class FirebaseAppInfo(typing_extensions.TypedDict, total=False):
    apiKeyId: str
    appId: str
    displayName: str
    name: str
    namespace: str
    platform: typing_extensions.Literal["PLATFORM_UNSPECIFIED", "IOS", "ANDROID", "WEB"]
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "ACTIVE", "DELETED"]

@typing.type_check_only
class FirebaseProject(typing_extensions.TypedDict, total=False):
    annotations: dict[str, typing.Any]
    displayName: str
    etag: str
    name: str
    projectId: str
    projectNumber: str
    resources: DefaultResources
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "ACTIVE", "DELETED"]

@typing.type_check_only
class IosApp(typing_extensions.TypedDict, total=False):
    apiKeyId: str
    appId: str
    appStoreId: str
    bundleId: str
    displayName: str
    name: str
    projectId: str
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "ACTIVE", "DELETED"]
    teamId: str

@typing.type_check_only
class IosAppConfig(typing_extensions.TypedDict, total=False):
    configFileContents: str
    configFilename: str

@typing.type_check_only
class ListAndroidAppsResponse(typing_extensions.TypedDict, total=False):
    apps: _list[AndroidApp]
    nextPageToken: str

@typing.type_check_only
class ListAvailableLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListAvailableProjectsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    projectInfo: _list[ProjectInfo]

@typing.type_check_only
class ListFirebaseProjectsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    results: _list[FirebaseProject]

@typing.type_check_only
class ListIosAppsResponse(typing_extensions.TypedDict, total=False):
    apps: _list[IosApp]
    nextPageToken: str

@typing.type_check_only
class ListShaCertificatesResponse(typing_extensions.TypedDict, total=False):
    certificates: _list[ShaCertificate]

@typing.type_check_only
class ListWebAppsResponse(typing_extensions.TypedDict, total=False):
    apps: _list[WebApp]
    nextPageToken: str

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    features: _list[str]
    locationId: str
    type: typing_extensions.Literal[
        "LOCATION_TYPE_UNSPECIFIED", "REGIONAL", "MULTI_REGIONAL"
    ]

@typing.type_check_only
class MessageSet(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class ProjectInfo(typing_extensions.TypedDict, total=False):
    displayName: str
    locationId: str
    project: str

@typing.type_check_only
class RemoveAnalyticsRequest(typing_extensions.TypedDict, total=False):
    analyticsPropertyId: str

@typing.type_check_only
class RemoveAndroidAppRequest(typing_extensions.TypedDict, total=False):
    allowMissing: bool
    etag: str
    validateOnly: bool

@typing.type_check_only
class RemoveIosAppRequest(typing_extensions.TypedDict, total=False):
    allowMissing: bool
    etag: str
    validateOnly: bool

@typing.type_check_only
class RemoveWebAppRequest(typing_extensions.TypedDict, total=False):
    allowMissing: bool
    etag: str
    validateOnly: bool

@typing.type_check_only
class SearchFirebaseAppsResponse(typing_extensions.TypedDict, total=False):
    apps: _list[FirebaseAppInfo]
    nextPageToken: str

@typing.type_check_only
class ShaCertificate(typing_extensions.TypedDict, total=False):
    certType: typing_extensions.Literal[
        "SHA_CERTIFICATE_TYPE_UNSPECIFIED", "SHA_1", "SHA_256"
    ]
    name: str
    shaHash: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class StatusProto(typing_extensions.TypedDict, total=False):
    canonicalCode: int
    code: int
    message: str
    messageSet: MessageSet
    space: str

@typing.type_check_only
class StreamMapping(typing_extensions.TypedDict, total=False):
    app: str
    measurementId: str
    streamId: str

@typing.type_check_only
class UndeleteAndroidAppRequest(typing_extensions.TypedDict, total=False):
    etag: str
    validateOnly: bool

@typing.type_check_only
class UndeleteIosAppRequest(typing_extensions.TypedDict, total=False):
    etag: str
    validateOnly: bool

@typing.type_check_only
class UndeleteWebAppRequest(typing_extensions.TypedDict, total=False):
    etag: str
    validateOnly: bool

@typing.type_check_only
class WebApp(typing_extensions.TypedDict, total=False):
    apiKeyId: str
    appId: str
    appUrls: _list[str]
    displayName: str
    name: str
    projectId: str
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "ACTIVE", "DELETED"]
    webId: str

@typing.type_check_only
class WebAppConfig(typing_extensions.TypedDict, total=False):
    apiKey: str
    appId: str
    authDomain: str
    databaseURL: str
    locationId: str
    measurementId: str
    messagingSenderId: str
    projectId: str
    storageBucket: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class Cardinality(typing_extensions.TypedDict, total=False):
    number: int
    path: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class EndCondition(typing_extensions.TypedDict, total=False):
    cardinality: Cardinality

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class ListConfigsResponse(typing_extensions.TypedDict, total=False):
    configs: _list[RuntimeConfig]
    nextPageToken: str

@typing.type_check_only
class ListVariablesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    variables: _list[Variable]

@typing.type_check_only
class ListWaitersResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    waiters: _list[Waiter]

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class RuntimeConfig(typing_extensions.TypedDict, total=False):
    description: str
    name: str

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: Policy

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class Variable(typing_extensions.TypedDict, total=False):
    name: str
    state: typing_extensions.Literal["VARIABLE_STATE_UNSPECIFIED", "UPDATED", "DELETED"]
    text: str
    updateTime: str
    value: str

@typing.type_check_only
class Waiter(typing_extensions.TypedDict, total=False):
    createTime: str
    done: bool
    error: Status
    failure: EndCondition
    name: str
    success: EndCondition
    timeout: str

@typing.type_check_only
class WatchVariableRequest(typing_extensions.TypedDict, total=False):
    newerThan: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class DigitalassetlinksResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AssetlinksResource(googleapiclient.discovery.Resource):
        def bulkCheck(
            self, *, body: BulkCheckRequest = ..., **kwargs: typing.Any
        ) -> BulkCheckResponseHttpRequest: ...
        def check(
            self,
            *,
            relation: str = ...,
            source_androidApp_certificate_sha256Fingerprint: str = ...,
            source_androidApp_packageName: str = ...,
            source_web_site: str = ...,
            target_androidApp_certificate_sha256Fingerprint: str = ...,
            target_androidApp_packageName: str = ...,
            target_web_site: str = ...,
            **kwargs: typing.Any
        ) -> CheckResponseHttpRequest: ...

    @typing.type_check_only
    class StatementsResource(googleapiclient.discovery.Resource):
        def list(
            self,
            *,
            relation: str = ...,
            source_androidApp_certificate_sha256Fingerprint: str = ...,
            source_androidApp_packageName: str = ...,
            source_web_site: str = ...,
            **kwargs: typing.Any
        ) -> ListResponseHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def assetlinks(self) -> AssetlinksResource: ...
    def statements(self) -> StatementsResource: ...

@typing.type_check_only
class BulkCheckResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BulkCheckResponse: ...

@typing.type_check_only
class CheckResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CheckResponse: ...

@typing.type_check_only
class ListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AuthorizationAttemptInfo(typing_extensions.TypedDict, total=False):
    details: str
    domain: str
    failureReason: typing_extensions.Literal[
        "FAILURE_REASON_UNSPECIFIED", "CONFIG", "CAA", "RATE_LIMITED"
    ]
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "AUTHORIZING", "AUTHORIZED", "FAILED"
    ]

@typing.type_check_only
class CancelOperationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Certificate(typing_extensions.TypedDict, total=False):
    createTime: str
    description: str
    expireTime: str
    labels: dict[str, typing.Any]
    managed: ManagedCertificate
    name: str
    pemCertificate: str
    sanDnsnames: _list[str]
    scope: typing_extensions.Literal["DEFAULT", "EDGE_CACHE"]
    selfManaged: SelfManagedCertificate
    updateTime: str

@typing.type_check_only
class CertificateAuthorityConfig(typing_extensions.TypedDict, total=False):
    certificateAuthorityServiceConfig: CertificateAuthorityServiceConfig

@typing.type_check_only
class CertificateAuthorityServiceConfig(typing_extensions.TypedDict, total=False):
    caPool: str

@typing.type_check_only
class CertificateIssuanceConfig(typing_extensions.TypedDict, total=False):
    certificateAuthorityConfig: CertificateAuthorityConfig
    createTime: str
    description: str
    keyAlgorithm: typing_extensions.Literal[
        "KEY_ALGORITHM_UNSPECIFIED", "RSA_2048", "ECDSA_P256"
    ]
    labels: dict[str, typing.Any]
    lifetime: str
    name: str
    rotationWindowPercentage: int
    updateTime: str

@typing.type_check_only
class CertificateMap(typing_extensions.TypedDict, total=False):
    createTime: str
    description: str
    gclbTargets: _list[GclbTarget]
    labels: dict[str, typing.Any]
    name: str
    updateTime: str

@typing.type_check_only
class CertificateMapEntry(typing_extensions.TypedDict, total=False):
    certificates: _list[str]
    createTime: str
    description: str
    hostname: str
    labels: dict[str, typing.Any]
    matcher: typing_extensions.Literal["MATCHER_UNSPECIFIED", "PRIMARY"]
    name: str
    state: typing_extensions.Literal["SERVING_STATE_UNSPECIFIED", "ACTIVE", "PENDING"]
    updateTime: str

@typing.type_check_only
class DnsAuthorization(typing_extensions.TypedDict, total=False):
    createTime: str
    description: str
    dnsResourceRecord: DnsResourceRecord
    domain: str
    labels: dict[str, typing.Any]
    name: str
    updateTime: str

@typing.type_check_only
class DnsResourceRecord(typing_extensions.TypedDict, total=False):
    data: str
    name: str
    type: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GclbTarget(typing_extensions.TypedDict, total=False):
    ipConfigs: _list[IpConfig]
    targetHttpsProxy: str
    targetSslProxy: str

@typing.type_check_only
class IpConfig(typing_extensions.TypedDict, total=False):
    ipAddress: str
    ports: _list[int]

@typing.type_check_only
class ListCertificateIssuanceConfigsResponse(typing_extensions.TypedDict, total=False):
    certificateIssuanceConfigs: _list[CertificateIssuanceConfig]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListCertificateMapEntriesResponse(typing_extensions.TypedDict, total=False):
    certificateMapEntries: _list[CertificateMapEntry]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListCertificateMapsResponse(typing_extensions.TypedDict, total=False):
    certificateMaps: _list[CertificateMap]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListCertificatesResponse(typing_extensions.TypedDict, total=False):
    certificates: _list[Certificate]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListDnsAuthorizationsResponse(typing_extensions.TypedDict, total=False):
    dnsAuthorizations: _list[DnsAuthorization]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class ManagedCertificate(typing_extensions.TypedDict, total=False):
    authorizationAttemptInfo: _list[AuthorizationAttemptInfo]
    dnsAuthorizations: _list[str]
    domains: _list[str]
    issuanceConfig: str
    provisioningIssue: ProvisioningIssue
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "PROVISIONING", "FAILED", "ACTIVE"
    ]

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OperationMetadata(typing_extensions.TypedDict, total=False):
    apiVersion: str
    createTime: str
    endTime: str
    requestedCancellation: bool
    statusMessage: str
    target: str
    verb: str

@typing.type_check_only
class ProvisioningIssue(typing_extensions.TypedDict, total=False):
    details: str
    reason: typing_extensions.Literal[
        "REASON_UNSPECIFIED", "AUTHORIZATION_ISSUE", "RATE_LIMITED"
    ]

@typing.type_check_only
class SelfManagedCertificate(typing_extensions.TypedDict, total=False):
    pemCertificate: str
    pemPrivateKey: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CloudIotResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class RegistriesResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class DevicesResource(googleapiclient.discovery.Resource):
                    @typing.type_check_only
                    class ConfigVersionsResource(googleapiclient.discovery.Resource):
                        def list(
                            self,
                            *,
                            name: str,
                            numVersions: int = ...,
                            **kwargs: typing.Any
                        ) -> ListDeviceConfigVersionsResponseHttpRequest: ...

                    @typing.type_check_only
                    class StatesResource(googleapiclient.discovery.Resource):
                        def list(
                            self,
                            *,
                            name: str,
                            numStates: int = ...,
                            **kwargs: typing.Any
                        ) -> ListDeviceStatesResponseHttpRequest: ...

                    def create(
                        self, *, parent: str, body: Device = ..., **kwargs: typing.Any
                    ) -> DeviceHttpRequest: ...
                    def delete(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> EmptyHttpRequest: ...
                    def get(
                        self, *, name: str, fieldMask: str = ..., **kwargs: typing.Any
                    ) -> DeviceHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        deviceIds: str | _list[str] = ...,
                        deviceNumIds: str | _list[str] = ...,
                        fieldMask: str = ...,
                        gatewayListOptions_associationsDeviceId: str = ...,
                        gatewayListOptions_associationsGatewayId: str = ...,
                        gatewayListOptions_gatewayType: typing_extensions.Literal[
                            "GATEWAY_TYPE_UNSPECIFIED", "GATEWAY", "NON_GATEWAY"
                        ] = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListDevicesResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListDevicesResponseHttpRequest,
                        previous_response: ListDevicesResponse,
                    ) -> ListDevicesResponseHttpRequest | None: ...
                    def modifyCloudToDeviceConfig(
                        self,
                        *,
                        name: str,
                        body: ModifyCloudToDeviceConfigRequest = ...,
                        **kwargs: typing.Any
                    ) -> DeviceConfigHttpRequest: ...
                    def patch(
                        self,
                        *,
                        name: str,
                        body: Device = ...,
                        updateMask: str = ...,
                        **kwargs: typing.Any
                    ) -> DeviceHttpRequest: ...
                    def sendCommandToDevice(
                        self,
                        *,
                        name: str,
                        body: SendCommandToDeviceRequest = ...,
                        **kwargs: typing.Any
                    ) -> SendCommandToDeviceResponseHttpRequest: ...
                    def configVersions(self) -> ConfigVersionsResource: ...
                    def states(self) -> StatesResource: ...

                @typing.type_check_only
                class GroupsResource(googleapiclient.discovery.Resource):
                    @typing.type_check_only
                    class DevicesResource(googleapiclient.discovery.Resource):
                        def list(
                            self,
                            *,
                            parent: str,
                            deviceIds: str | _list[str] = ...,
                            deviceNumIds: str | _list[str] = ...,
                            fieldMask: str = ...,
                            gatewayListOptions_associationsDeviceId: str = ...,
                            gatewayListOptions_associationsGatewayId: str = ...,
                            gatewayListOptions_gatewayType: typing_extensions.Literal[
                                "GATEWAY_TYPE_UNSPECIFIED", "GATEWAY", "NON_GATEWAY"
                            ] = ...,
                            pageSize: int = ...,
                            pageToken: str = ...,
                            **kwargs: typing.Any
                        ) -> ListDevicesResponseHttpRequest: ...
                        def list_next(
                            self,
                            previous_request: ListDevicesResponseHttpRequest,
                            previous_response: ListDevicesResponse,
                        ) -> ListDevicesResponseHttpRequest | None: ...

                    def getIamPolicy(
                        self,
                        *,
                        resource: str,
                        body: GetIamPolicyRequest = ...,
                        **kwargs: typing.Any
                    ) -> PolicyHttpRequest: ...
                    def setIamPolicy(
                        self,
                        *,
                        resource: str,
                        body: SetIamPolicyRequest = ...,
                        **kwargs: typing.Any
                    ) -> PolicyHttpRequest: ...
                    def testIamPermissions(
                        self,
                        *,
                        resource: str,
                        body: TestIamPermissionsRequest = ...,
                        **kwargs: typing.Any
                    ) -> TestIamPermissionsResponseHttpRequest: ...
                    def devices(self) -> DevicesResource: ...

                def bindDeviceToGateway(
                    self,
                    *,
                    parent: str,
                    body: BindDeviceToGatewayRequest = ...,
                    **kwargs: typing.Any
                ) -> BindDeviceToGatewayResponseHttpRequest: ...
                def create(
                    self,
                    *,
                    parent: str,
                    body: DeviceRegistry = ...,
                    **kwargs: typing.Any
                ) -> DeviceRegistryHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> DeviceRegistryHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: GetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListDeviceRegistriesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListDeviceRegistriesResponseHttpRequest,
                    previous_response: ListDeviceRegistriesResponse,
                ) -> ListDeviceRegistriesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: DeviceRegistry = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> DeviceRegistryHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...
                def unbindDeviceFromGateway(
                    self,
                    *,
                    parent: str,
                    body: UnbindDeviceFromGatewayRequest = ...,
                    **kwargs: typing.Any
                ) -> UnbindDeviceFromGatewayResponseHttpRequest: ...
                def devices(self) -> DevicesResource: ...
                def groups(self) -> GroupsResource: ...

            def registries(self) -> RegistriesResource: ...

        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class BindDeviceToGatewayResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BindDeviceToGatewayResponse: ...

@typing.type_check_only
class DeviceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Device: ...

@typing.type_check_only
class DeviceConfigHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DeviceConfig: ...

@typing.type_check_only
class DeviceRegistryHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DeviceRegistry: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListDeviceConfigVersionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListDeviceConfigVersionsResponse: ...

@typing.type_check_only
class ListDeviceRegistriesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListDeviceRegistriesResponse: ...

@typing.type_check_only
class ListDeviceStatesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListDeviceStatesResponse: ...

@typing.type_check_only
class ListDevicesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListDevicesResponse: ...

@typing.type_check_only
class PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Policy: ...

@typing.type_check_only
class SendCommandToDeviceResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SendCommandToDeviceResponse: ...

@typing.type_check_only
class TestIamPermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TestIamPermissionsResponse: ...

@typing.type_check_only
class UnbindDeviceFromGatewayResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> UnbindDeviceFromGatewayResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleCloudOrgpolicyV2AlternatePolicySpec(
    typing_extensions.TypedDict, total=False
):
    launch: str
    spec: GoogleCloudOrgpolicyV2PolicySpec

@typing.type_check_only
class GoogleCloudOrgpolicyV2Constraint(typing_extensions.TypedDict, total=False):
    booleanConstraint: GoogleCloudOrgpolicyV2ConstraintBooleanConstraint
    constraintDefault: typing_extensions.Literal[
        "CONSTRAINT_DEFAULT_UNSPECIFIED", "ALLOW", "DENY"
    ]
    description: str
    displayName: str
    listConstraint: GoogleCloudOrgpolicyV2ConstraintListConstraint
    name: str

@typing.type_check_only
class GoogleCloudOrgpolicyV2ConstraintBooleanConstraint(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudOrgpolicyV2ConstraintListConstraint(
    typing_extensions.TypedDict, total=False
):
    supportsIn: bool
    supportsUnder: bool

@typing.type_check_only
class GoogleCloudOrgpolicyV2CustomConstraint(typing_extensions.TypedDict, total=False):
    actionType: typing_extensions.Literal["ACTION_TYPE_UNSPECIFIED", "ALLOW", "DENY"]
    condition: str
    description: str
    displayName: str
    methodTypes: _list[str]
    name: str
    resourceTypes: _list[str]
    updateTime: str

@typing.type_check_only
class GoogleCloudOrgpolicyV2ListConstraintsResponse(
    typing_extensions.TypedDict, total=False
):
    constraints: _list[GoogleCloudOrgpolicyV2Constraint]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudOrgpolicyV2ListCustomConstraintsResponse(
    typing_extensions.TypedDict, total=False
):
    customConstraints: _list[GoogleCloudOrgpolicyV2CustomConstraint]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudOrgpolicyV2ListPoliciesResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    policies: _list[GoogleCloudOrgpolicyV2Policy]

@typing.type_check_only
class GoogleCloudOrgpolicyV2Policy(typing_extensions.TypedDict, total=False):
    alternate: GoogleCloudOrgpolicyV2AlternatePolicySpec
    name: str
    spec: GoogleCloudOrgpolicyV2PolicySpec

@typing.type_check_only
class GoogleCloudOrgpolicyV2PolicySpec(typing_extensions.TypedDict, total=False):
    etag: str
    inheritFromParent: bool
    reset: bool
    rules: _list[GoogleCloudOrgpolicyV2PolicySpecPolicyRule]
    updateTime: str

@typing.type_check_only
class GoogleCloudOrgpolicyV2PolicySpecPolicyRule(
    typing_extensions.TypedDict, total=False
):
    allowAll: bool
    condition: GoogleTypeExpr
    denyAll: bool
    enforce: bool
    values: GoogleCloudOrgpolicyV2PolicySpecPolicyRuleStringValues

@typing.type_check_only
class GoogleCloudOrgpolicyV2PolicySpecPolicyRuleStringValues(
    typing_extensions.TypedDict, total=False
):
    allowedValues: _list[str]
    deniedValues: _list[str]

@typing.type_check_only
class GoogleProtobufEmpty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GoogleTypeExpr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class ServiceNetworkingResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class OperationsResource(googleapiclient.discovery.Resource):
        def cancel(
            self, *, name: str, body: CancelOperationRequest = ..., **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...
        def delete(self, *, name: str, **kwargs: typing.Any) -> EmptyHttpRequest: ...
        def get(self, *, name: str, **kwargs: typing.Any) -> OperationHttpRequest: ...
        def list(
            self,
            *,
            name: str,
            filter: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListOperationsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListOperationsResponseHttpRequest,
            previous_response: ListOperationsResponse,
        ) -> ListOperationsResponseHttpRequest | None: ...

    @typing.type_check_only
    class ServicesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ConnectionsResource(googleapiclient.discovery.Resource):
            def create(
                self, *, parent: str, body: Connection = ..., **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def deleteConnection(
                self,
                *,
                name: str,
                body: DeleteConnectionRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def list(
                self, *, parent: str, network: str = ..., **kwargs: typing.Any
            ) -> ListConnectionsResponseHttpRequest: ...
            def patch(
                self,
                *,
                name: str,
                body: Connection = ...,
                force: bool = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        @typing.type_check_only
        class DnsRecordSetsResource(googleapiclient.discovery.Resource):
            def add(
                self,
                *,
                parent: str,
                body: AddDnsRecordSetRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def remove(
                self,
                *,
                parent: str,
                body: RemoveDnsRecordSetRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def update(
                self,
                *,
                parent: str,
                body: UpdateDnsRecordSetRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        @typing.type_check_only
        class DnsZonesResource(googleapiclient.discovery.Resource):
            def add(
                self,
                *,
                parent: str,
                body: AddDnsZoneRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def remove(
                self,
                *,
                parent: str,
                body: RemoveDnsZoneRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        @typing.type_check_only
        class ProjectsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class GlobalResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class NetworksResource(googleapiclient.discovery.Resource):
                    @typing.type_check_only
                    class PeeredDnsDomainsResource(googleapiclient.discovery.Resource):
                        def create(
                            self,
                            *,
                            parent: str,
                            body: PeeredDnsDomain = ...,
                            **kwargs: typing.Any
                        ) -> OperationHttpRequest: ...
                        def delete(
                            self, *, name: str, **kwargs: typing.Any
                        ) -> OperationHttpRequest: ...
                        def list(
                            self, *, parent: str, **kwargs: typing.Any
                        ) -> ListPeeredDnsDomainsResponseHttpRequest: ...

                    def get(
                        self,
                        *,
                        name: str,
                        includeUsedIpRanges: bool = ...,
                        **kwargs: typing.Any
                    ) -> ConsumerConfigHttpRequest: ...
                    def updateConsumerConfig(
                        self,
                        *,
                        parent: str,
                        body: UpdateConsumerConfigRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def peeredDnsDomains(self) -> PeeredDnsDomainsResource: ...

                def networks(self) -> NetworksResource: ...

            def global_(self) -> GlobalResource: ...

        @typing.type_check_only
        class RolesResource(googleapiclient.discovery.Resource):
            def add(
                self, *, parent: str, body: AddRolesRequest = ..., **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        def addSubnetwork(
            self, *, parent: str, body: AddSubnetworkRequest = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def disableVpcServiceControls(
            self,
            *,
            parent: str,
            body: DisableVpcServiceControlsRequest = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def enableVpcServiceControls(
            self,
            *,
            parent: str,
            body: EnableVpcServiceControlsRequest = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def searchRange(
            self, *, parent: str, body: SearchRangeRequest = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def validate(
            self,
            *,
            parent: str,
            body: ValidateConsumerConfigRequest = ...,
            **kwargs: typing.Any
        ) -> ValidateConsumerConfigResponseHttpRequest: ...
        def connections(self) -> ConnectionsResource: ...
        def dnsRecordSets(self) -> DnsRecordSetsResource: ...
        def dnsZones(self) -> DnsZonesResource: ...
        def projects(self) -> ProjectsResource: ...
        def roles(self) -> RolesResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def operations(self) -> OperationsResource: ...
    def services(self) -> ServicesResource: ...

@typing.type_check_only
class ConsumerConfigHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ConsumerConfig: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListConnectionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListConnectionsResponse: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class ListPeeredDnsDomainsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListPeeredDnsDomainsResponse: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class ValidateConsumerConfigResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ValidateConsumerConfigResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class ClaimDeviceRequest(typing_extensions.TypedDict, total=False):
    customerId: str
    deviceIdentifier: DeviceIdentifier
    deviceMetadata: DeviceMetadata
    sectionType: typing_extensions.Literal[
        "SECTION_TYPE_UNSPECIFIED", "SECTION_TYPE_SIM_LOCK", "SECTION_TYPE_ZERO_TOUCH"
    ]

@typing.type_check_only
class ClaimDeviceResponse(typing_extensions.TypedDict, total=False):
    deviceId: str
    deviceName: str

@typing.type_check_only
class ClaimDevicesRequest(typing_extensions.TypedDict, total=False):
    claims: _list[PartnerClaim]

@typing.type_check_only
class Company(typing_extensions.TypedDict, total=False):
    adminEmails: _list[str]
    companyId: str
    companyName: str
    languageCode: str
    name: str
    ownerEmails: _list[str]
    skipWelcomeEmail: bool
    termsStatus: typing_extensions.Literal[
        "TERMS_STATUS_UNSPECIFIED",
        "TERMS_STATUS_NOT_ACCEPTED",
        "TERMS_STATUS_ACCEPTED",
        "TERMS_STATUS_STALE",
    ]

@typing.type_check_only
class Configuration(typing_extensions.TypedDict, total=False):
    companyName: str
    configurationId: str
    configurationName: str
    contactEmail: str
    contactPhone: str
    customMessage: str
    dpcExtras: str
    dpcResourcePath: str
    isDefault: bool
    name: str

@typing.type_check_only
class CreateCustomerRequest(typing_extensions.TypedDict, total=False):
    customer: Company

@typing.type_check_only
class CustomerApplyConfigurationRequest(typing_extensions.TypedDict, total=False):
    configuration: str
    device: DeviceReference

@typing.type_check_only
class CustomerListConfigurationsResponse(typing_extensions.TypedDict, total=False):
    configurations: _list[Configuration]

@typing.type_check_only
class CustomerListCustomersResponse(typing_extensions.TypedDict, total=False):
    customers: _list[Company]
    nextPageToken: str

@typing.type_check_only
class CustomerListDevicesResponse(typing_extensions.TypedDict, total=False):
    devices: _list[Device]
    nextPageToken: str

@typing.type_check_only
class CustomerListDpcsResponse(typing_extensions.TypedDict, total=False):
    dpcs: _list[Dpc]

@typing.type_check_only
class CustomerRemoveConfigurationRequest(typing_extensions.TypedDict, total=False):
    device: DeviceReference

@typing.type_check_only
class CustomerUnclaimDeviceRequest(typing_extensions.TypedDict, total=False):
    device: DeviceReference

@typing.type_check_only
class Device(typing_extensions.TypedDict, total=False):
    claims: _list[DeviceClaim]
    configuration: str
    deviceId: str
    deviceIdentifier: DeviceIdentifier
    deviceMetadata: DeviceMetadata
    name: str

@typing.type_check_only
class DeviceClaim(typing_extensions.TypedDict, total=False):
    additionalService: typing_extensions.Literal[
        "ADDITIONAL_SERVICE_UNSPECIFIED", "DEVICE_PROTECTION"
    ]
    ownerCompanyId: str
    resellerId: str
    sectionType: typing_extensions.Literal[
        "SECTION_TYPE_UNSPECIFIED", "SECTION_TYPE_SIM_LOCK", "SECTION_TYPE_ZERO_TOUCH"
    ]
    vacationModeExpireTime: str
    vacationModeStartTime: str

@typing.type_check_only
class DeviceIdentifier(typing_extensions.TypedDict, total=False):
    imei: str
    manufacturer: str
    meid: str
    model: str
    serialNumber: str

@typing.type_check_only
class DeviceMetadata(typing_extensions.TypedDict, total=False):
    entries: dict[str, typing.Any]

@typing.type_check_only
class DeviceReference(typing_extensions.TypedDict, total=False):
    deviceId: str
    deviceIdentifier: DeviceIdentifier

@typing.type_check_only
class DevicesLongRunningOperationMetadata(typing_extensions.TypedDict, total=False):
    devicesCount: int
    processingStatus: typing_extensions.Literal[
        "BATCH_PROCESS_STATUS_UNSPECIFIED",
        "BATCH_PROCESS_PENDING",
        "BATCH_PROCESS_IN_PROGRESS",
        "BATCH_PROCESS_PROCESSED",
    ]
    progress: int

@typing.type_check_only
class DevicesLongRunningOperationResponse(typing_extensions.TypedDict, total=False):
    perDeviceStatus: _list[OperationPerDevice]
    successCount: int

@typing.type_check_only
class Dpc(typing_extensions.TypedDict, total=False):
    dpcName: str
    name: str
    packageName: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class FindDevicesByDeviceIdentifierRequest(typing_extensions.TypedDict, total=False):
    deviceIdentifier: DeviceIdentifier
    limit: str
    pageToken: str

@typing.type_check_only
class FindDevicesByDeviceIdentifierResponse(typing_extensions.TypedDict, total=False):
    devices: _list[Device]
    nextPageToken: str
    totalSize: int

@typing.type_check_only
class FindDevicesByOwnerRequest(typing_extensions.TypedDict, total=False):
    customerId: _list[str]
    limit: str
    pageToken: str
    sectionType: typing_extensions.Literal[
        "SECTION_TYPE_UNSPECIFIED", "SECTION_TYPE_SIM_LOCK", "SECTION_TYPE_ZERO_TOUCH"
    ]

@typing.type_check_only
class FindDevicesByOwnerResponse(typing_extensions.TypedDict, total=False):
    devices: _list[Device]
    nextPageToken: str
    totalSize: int

@typing.type_check_only
class ListCustomersResponse(typing_extensions.TypedDict, total=False):
    customers: _list[Company]
    nextPageToken: str
    totalSize: int

@typing.type_check_only
class ListVendorCustomersResponse(typing_extensions.TypedDict, total=False):
    customers: _list[Company]
    nextPageToken: str
    totalSize: int

@typing.type_check_only
class ListVendorsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    totalSize: int
    vendors: _list[Company]

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OperationPerDevice(typing_extensions.TypedDict, total=False):
    claim: PartnerClaim
    result: PerDeviceStatusInBatch
    unclaim: PartnerUnclaim
    updateMetadata: UpdateMetadataArguments

@typing.type_check_only
class PartnerClaim(typing_extensions.TypedDict, total=False):
    customerId: str
    deviceIdentifier: DeviceIdentifier
    deviceMetadata: DeviceMetadata
    sectionType: typing_extensions.Literal[
        "SECTION_TYPE_UNSPECIFIED", "SECTION_TYPE_SIM_LOCK", "SECTION_TYPE_ZERO_TOUCH"
    ]

@typing.type_check_only
class PartnerUnclaim(typing_extensions.TypedDict, total=False):
    deviceId: str
    deviceIdentifier: DeviceIdentifier
    sectionType: typing_extensions.Literal[
        "SECTION_TYPE_UNSPECIFIED", "SECTION_TYPE_SIM_LOCK", "SECTION_TYPE_ZERO_TOUCH"
    ]
    vacationModeDays: int
    vacationModeExpireTime: str

@typing.type_check_only
class PerDeviceStatusInBatch(typing_extensions.TypedDict, total=False):
    deviceId: str
    errorIdentifier: str
    errorMessage: str
    status: typing_extensions.Literal[
        "SINGLE_DEVICE_STATUS_UNSPECIFIED",
        "SINGLE_DEVICE_STATUS_UNKNOWN_ERROR",
        "SINGLE_DEVICE_STATUS_OTHER_ERROR",
        "SINGLE_DEVICE_STATUS_SUCCESS",
        "SINGLE_DEVICE_STATUS_PERMISSION_DENIED",
        "SINGLE_DEVICE_STATUS_INVALID_DEVICE_IDENTIFIER",
        "SINGLE_DEVICE_STATUS_INVALID_SECTION_TYPE",
        "SINGLE_DEVICE_STATUS_SECTION_NOT_YOURS",
    ]

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class UnclaimDeviceRequest(typing_extensions.TypedDict, total=False):
    deviceId: str
    deviceIdentifier: DeviceIdentifier
    sectionType: typing_extensions.Literal[
        "SECTION_TYPE_UNSPECIFIED", "SECTION_TYPE_SIM_LOCK", "SECTION_TYPE_ZERO_TOUCH"
    ]
    vacationModeDays: int
    vacationModeExpireTime: str

@typing.type_check_only
class UnclaimDevicesRequest(typing_extensions.TypedDict, total=False):
    unclaims: _list[PartnerUnclaim]

@typing.type_check_only
class UpdateDeviceMetadataInBatchRequest(typing_extensions.TypedDict, total=False):
    updates: _list[UpdateMetadataArguments]

@typing.type_check_only
class UpdateDeviceMetadataRequest(typing_extensions.TypedDict, total=False):
    deviceMetadata: DeviceMetadata

@typing.type_check_only
class UpdateMetadataArguments(typing_extensions.TypedDict, total=False):
    deviceId: str
    deviceIdentifier: DeviceIdentifier
    deviceMetadata: DeviceMetadata



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Announcement(typing_extensions.TypedDict, total=False):
    alternateLink: str
    assigneeMode: typing_extensions.Literal[
        "ASSIGNEE_MODE_UNSPECIFIED", "ALL_STUDENTS", "INDIVIDUAL_STUDENTS"
    ]
    courseId: str
    creationTime: str
    creatorUserId: str
    id: str
    individualStudentsOptions: IndividualStudentsOptions
    materials: _list[Material]
    scheduledTime: str
    state: typing_extensions.Literal[
        "ANNOUNCEMENT_STATE_UNSPECIFIED", "PUBLISHED", "DRAFT", "DELETED"
    ]
    text: str
    updateTime: str

@typing.type_check_only
class Assignment(typing_extensions.TypedDict, total=False):
    studentWorkFolder: DriveFolder

@typing.type_check_only
class AssignmentSubmission(typing_extensions.TypedDict, total=False):
    attachments: _list[Attachment]

@typing.type_check_only
class Attachment(typing_extensions.TypedDict, total=False):
    driveFile: DriveFile
    form: Form
    link: Link
    youTubeVideo: YouTubeVideo

@typing.type_check_only
class CloudPubsubTopic(typing_extensions.TypedDict, total=False):
    topicName: str

@typing.type_check_only
class Course(typing_extensions.TypedDict, total=False):
    alternateLink: str
    calendarId: str
    courseGroupEmail: str
    courseMaterialSets: _list[CourseMaterialSet]
    courseState: typing_extensions.Literal[
        "COURSE_STATE_UNSPECIFIED",
        "ACTIVE",
        "ARCHIVED",
        "PROVISIONED",
        "DECLINED",
        "SUSPENDED",
    ]
    creationTime: str
    description: str
    descriptionHeading: str
    enrollmentCode: str
    gradebookSettings: GradebookSettings
    guardiansEnabled: bool
    id: str
    name: str
    ownerId: str
    room: str
    section: str
    teacherFolder: DriveFolder
    teacherGroupEmail: str
    updateTime: str

@typing.type_check_only
class CourseAlias(typing_extensions.TypedDict, total=False):
    alias: str

@typing.type_check_only
class CourseMaterial(typing_extensions.TypedDict, total=False):
    driveFile: DriveFile
    form: Form
    link: Link
    youTubeVideo: YouTubeVideo

@typing.type_check_only
class CourseMaterialSet(typing_extensions.TypedDict, total=False):
    materials: _list[CourseMaterial]
    title: str

@typing.type_check_only
class CourseRosterChangesInfo(typing_extensions.TypedDict, total=False):
    courseId: str

@typing.type_check_only
class CourseWork(typing_extensions.TypedDict, total=False):
    alternateLink: str
    assigneeMode: typing_extensions.Literal[
        "ASSIGNEE_MODE_UNSPECIFIED", "ALL_STUDENTS", "INDIVIDUAL_STUDENTS"
    ]
    assignment: Assignment
    associatedWithDeveloper: bool
    courseId: str
    creationTime: str
    creatorUserId: str
    description: str
    dueDate: Date
    dueTime: TimeOfDay
    gradeCategory: GradeCategory
    id: str
    individualStudentsOptions: IndividualStudentsOptions
    materials: _list[Material]
    maxPoints: float
    multipleChoiceQuestion: MultipleChoiceQuestion
    scheduledTime: str
    state: typing_extensions.Literal[
        "COURSE_WORK_STATE_UNSPECIFIED", "PUBLISHED", "DRAFT", "DELETED"
    ]
    submissionModificationMode: typing_extensions.Literal[
        "SUBMISSION_MODIFICATION_MODE_UNSPECIFIED",
        "MODIFIABLE_UNTIL_TURNED_IN",
        "MODIFIABLE",
    ]
    title: str
    topicId: str
    updateTime: str
    workType: typing_extensions.Literal[
        "COURSE_WORK_TYPE_UNSPECIFIED",
        "ASSIGNMENT",
        "SHORT_ANSWER_QUESTION",
        "MULTIPLE_CHOICE_QUESTION",
    ]

@typing.type_check_only
class CourseWorkChangesInfo(typing_extensions.TypedDict, total=False):
    courseId: str

@typing.type_check_only
class CourseWorkMaterial(typing_extensions.TypedDict, total=False):
    alternateLink: str
    assigneeMode: typing_extensions.Literal[
        "ASSIGNEE_MODE_UNSPECIFIED", "ALL_STUDENTS", "INDIVIDUAL_STUDENTS"
    ]
    courseId: str
    creationTime: str
    creatorUserId: str
    description: str
    id: str
    individualStudentsOptions: IndividualStudentsOptions
    materials: _list[Material]
    scheduledTime: str
    state: typing_extensions.Literal[
        "COURSEWORK_MATERIAL_STATE_UNSPECIFIED", "PUBLISHED", "DRAFT", "DELETED"
    ]
    title: str
    topicId: str
    updateTime: str

@typing.type_check_only
class Date(typing_extensions.TypedDict, total=False):
    day: int
    month: int
    year: int

@typing.type_check_only
class DriveFile(typing_extensions.TypedDict, total=False):
    alternateLink: str
    id: str
    thumbnailUrl: str
    title: str

@typing.type_check_only
class DriveFolder(typing_extensions.TypedDict, total=False):
    alternateLink: str
    id: str
    title: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Feed(typing_extensions.TypedDict, total=False):
    courseRosterChangesInfo: CourseRosterChangesInfo
    courseWorkChangesInfo: CourseWorkChangesInfo
    feedType: typing_extensions.Literal[
        "FEED_TYPE_UNSPECIFIED",
        "DOMAIN_ROSTER_CHANGES",
        "COURSE_ROSTER_CHANGES",
        "COURSE_WORK_CHANGES",
    ]

@typing.type_check_only
class Form(typing_extensions.TypedDict, total=False):
    formUrl: str
    responseUrl: str
    thumbnailUrl: str
    title: str

@typing.type_check_only
class GlobalPermission(typing_extensions.TypedDict, total=False):
    permission: typing_extensions.Literal["PERMISSION_UNSPECIFIED", "CREATE_COURSE"]

@typing.type_check_only
class GradeCategory(typing_extensions.TypedDict, total=False):
    defaultGradeDenominator: int
    id: str
    name: str
    weight: int

@typing.type_check_only
class GradeHistory(typing_extensions.TypedDict, total=False):
    actorUserId: str
    gradeChangeType: typing_extensions.Literal[
        "UNKNOWN_GRADE_CHANGE_TYPE",
        "DRAFT_GRADE_POINTS_EARNED_CHANGE",
        "ASSIGNED_GRADE_POINTS_EARNED_CHANGE",
        "MAX_POINTS_CHANGE",
    ]
    gradeTimestamp: str
    maxPoints: float
    pointsEarned: float

@typing.type_check_only
class GradebookSettings(typing_extensions.TypedDict, total=False):
    calculationType: typing_extensions.Literal[
        "CALCULATION_TYPE_UNSPECIFIED", "TOTAL_POINTS", "WEIGHTED_CATEGORIES"
    ]
    displaySetting: typing_extensions.Literal[
        "DISPLAY_SETTING_UNSPECIFIED",
        "SHOW_OVERALL_GRADE",
        "HIDE_OVERALL_GRADE",
        "SHOW_TEACHERS_ONLY",
    ]
    gradeCategories: _list[GradeCategory]

@typing.type_check_only
class Guardian(typing_extensions.TypedDict, total=False):
    guardianId: str
    guardianProfile: UserProfile
    invitedEmailAddress: str
    studentId: str

@typing.type_check_only
class GuardianInvitation(typing_extensions.TypedDict, total=False):
    creationTime: str
    invitationId: str
    invitedEmailAddress: str
    state: typing_extensions.Literal[
        "GUARDIAN_INVITATION_STATE_UNSPECIFIED", "PENDING", "COMPLETE"
    ]
    studentId: str

@typing.type_check_only
class IndividualStudentsOptions(typing_extensions.TypedDict, total=False):
    studentIds: _list[str]

@typing.type_check_only
class Invitation(typing_extensions.TypedDict, total=False):
    courseId: str
    id: str
    role: typing_extensions.Literal[
        "COURSE_ROLE_UNSPECIFIED", "STUDENT", "TEACHER", "OWNER"
    ]
    userId: str

@typing.type_check_only
class Link(typing_extensions.TypedDict, total=False):
    thumbnailUrl: str
    title: str
    url: str

@typing.type_check_only
class ListAnnouncementsResponse(typing_extensions.TypedDict, total=False):
    announcements: _list[Announcement]
    nextPageToken: str

@typing.type_check_only
class ListCourseAliasesResponse(typing_extensions.TypedDict, total=False):
    aliases: _list[CourseAlias]
    nextPageToken: str

@typing.type_check_only
class ListCourseWorkMaterialResponse(typing_extensions.TypedDict, total=False):
    courseWorkMaterial: _list[CourseWorkMaterial]
    nextPageToken: str

@typing.type_check_only
class ListCourseWorkResponse(typing_extensions.TypedDict, total=False):
    courseWork: _list[CourseWork]
    nextPageToken: str

@typing.type_check_only
class ListCoursesResponse(typing_extensions.TypedDict, total=False):
    courses: _list[Course]
    nextPageToken: str

@typing.type_check_only
class ListGuardianInvitationsResponse(typing_extensions.TypedDict, total=False):
    guardianInvitations: _list[GuardianInvitation]
    nextPageToken: str

@typing.type_check_only
class ListGuardiansResponse(typing_extensions.TypedDict, total=False):
    guardians: _list[Guardian]
    nextPageToken: str

@typing.type_check_only
class ListInvitationsResponse(typing_extensions.TypedDict, total=False):
    invitations: _list[Invitation]
    nextPageToken: str

@typing.type_check_only
class ListStudentSubmissionsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    studentSubmissions: _list[StudentSubmission]

@typing.type_check_only
class ListStudentsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    students: _list[Student]

@typing.type_check_only
class ListTeachersResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    teachers: _list[Teacher]

@typing.type_check_only
class ListTopicResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    topic: _list[Topic]

@typing.type_check_only
class Material(typing_extensions.TypedDict, total=False):
    driveFile: SharedDriveFile
    form: Form
    link: Link
    youtubeVideo: YouTubeVideo

@typing.type_check_only
class ModifyAnnouncementAssigneesRequest(typing_extensions.TypedDict, total=False):
    assigneeMode: typing_extensions.Literal[
        "ASSIGNEE_MODE_UNSPECIFIED", "ALL_STUDENTS", "INDIVIDUAL_STUDENTS"
    ]
    modifyIndividualStudentsOptions: ModifyIndividualStudentsOptions

@typing.type_check_only
class ModifyAttachmentsRequest(typing_extensions.TypedDict, total=False):
    addAttachments: _list[Attachment]

@typing.type_check_only
class ModifyCourseWorkAssigneesRequest(typing_extensions.TypedDict, total=False):
    assigneeMode: typing_extensions.Literal[
        "ASSIGNEE_MODE_UNSPECIFIED", "ALL_STUDENTS", "INDIVIDUAL_STUDENTS"
    ]
    modifyIndividualStudentsOptions: ModifyIndividualStudentsOptions

@typing.type_check_only
class ModifyIndividualStudentsOptions(typing_extensions.TypedDict, total=False):
    addStudentIds: _list[str]
    removeStudentIds: _list[str]

@typing.type_check_only
class MultipleChoiceQuestion(typing_extensions.TypedDict, total=False):
    choices: _list[str]

@typing.type_check_only
class MultipleChoiceSubmission(typing_extensions.TypedDict, total=False):
    answer: str

@typing.type_check_only
class Name(typing_extensions.TypedDict, total=False):
    familyName: str
    fullName: str
    givenName: str

@typing.type_check_only
class ReclaimStudentSubmissionRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Registration(typing_extensions.TypedDict, total=False):
    cloudPubsubTopic: CloudPubsubTopic
    expiryTime: str
    feed: Feed
    registrationId: str

@typing.type_check_only
class ReturnStudentSubmissionRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class SharedDriveFile(typing_extensions.TypedDict, total=False):
    driveFile: DriveFile
    shareMode: typing_extensions.Literal[
        "UNKNOWN_SHARE_MODE", "VIEW", "EDIT", "STUDENT_COPY"
    ]

@typing.type_check_only
class ShortAnswerSubmission(typing_extensions.TypedDict, total=False):
    answer: str

@typing.type_check_only
class StateHistory(typing_extensions.TypedDict, total=False):
    actorUserId: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "CREATED",
        "TURNED_IN",
        "RETURNED",
        "RECLAIMED_BY_STUDENT",
        "STUDENT_EDITED_AFTER_TURN_IN",
    ]
    stateTimestamp: str

@typing.type_check_only
class Student(typing_extensions.TypedDict, total=False):
    courseId: str
    profile: UserProfile
    studentWorkFolder: DriveFolder
    userId: str

@typing.type_check_only
class StudentSubmission(typing_extensions.TypedDict, total=False):
    alternateLink: str
    assignedGrade: float
    assignmentSubmission: AssignmentSubmission
    associatedWithDeveloper: bool
    courseId: str
    courseWorkId: str
    courseWorkType: typing_extensions.Literal[
        "COURSE_WORK_TYPE_UNSPECIFIED",
        "ASSIGNMENT",
        "SHORT_ANSWER_QUESTION",
        "MULTIPLE_CHOICE_QUESTION",
    ]
    creationTime: str
    draftGrade: float
    id: str
    late: bool
    multipleChoiceSubmission: MultipleChoiceSubmission
    shortAnswerSubmission: ShortAnswerSubmission
    state: typing_extensions.Literal[
        "SUBMISSION_STATE_UNSPECIFIED",
        "NEW",
        "CREATED",
        "TURNED_IN",
        "RETURNED",
        "RECLAIMED_BY_STUDENT",
    ]
    submissionHistory: _list[SubmissionHistory]
    updateTime: str
    userId: str

@typing.type_check_only
class SubmissionHistory(typing_extensions.TypedDict, total=False):
    gradeHistory: GradeHistory
    stateHistory: StateHistory

@typing.type_check_only
class Teacher(typing_extensions.TypedDict, total=False):
    courseId: str
    profile: UserProfile
    userId: str

@typing.type_check_only
class TimeOfDay(typing_extensions.TypedDict, total=False):
    hours: int
    minutes: int
    nanos: int
    seconds: int

@typing.type_check_only
class Topic(typing_extensions.TypedDict, total=False):
    courseId: str
    name: str
    topicId: str
    updateTime: str

@typing.type_check_only
class TurnInStudentSubmissionRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class UserProfile(typing_extensions.TypedDict, total=False):
    emailAddress: str
    id: str
    name: Name
    permissions: _list[GlobalPermission]
    photoUrl: str
    verifiedTeacher: bool

@typing.type_check_only
class YouTubeVideo(typing_extensions.TypedDict, total=False):
    alternateLink: str
    id: str
    thumbnailUrl: str
    title: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class FirebaseRulesResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ReleasesResource(googleapiclient.discovery.Resource):
            def create(
                self, *, name: str, body: Release = ..., **kwargs: typing.Any
            ) -> ReleaseHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(self, *, name: str, **kwargs: typing.Any) -> ReleaseHttpRequest: ...
            def getExecutable(
                self,
                *,
                name: str,
                executableVersion: typing_extensions.Literal[
                    "RELEASE_EXECUTABLE_VERSION_UNSPECIFIED",
                    "FIREBASE_RULES_EXECUTABLE_V1",
                    "FIREBASE_RULES_EXECUTABLE_V2",
                ] = ...,
                **kwargs: typing.Any
            ) -> GetReleaseExecutableResponseHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListReleasesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListReleasesResponseHttpRequest,
                previous_response: ListReleasesResponse,
            ) -> ListReleasesResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: UpdateReleaseRequest = ...,
                **kwargs: typing.Any
            ) -> ReleaseHttpRequest: ...

        @typing.type_check_only
        class RulesetsResource(googleapiclient.discovery.Resource):
            def create(
                self, *, name: str, body: Ruleset = ..., **kwargs: typing.Any
            ) -> RulesetHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(self, *, name: str, **kwargs: typing.Any) -> RulesetHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListRulesetsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListRulesetsResponseHttpRequest,
                previous_response: ListRulesetsResponse,
            ) -> ListRulesetsResponseHttpRequest | None: ...

        def test(
            self, *, name: str, body: TestRulesetRequest = ..., **kwargs: typing.Any
        ) -> TestRulesetResponseHttpRequest: ...
        def releases(self) -> ReleasesResource: ...
        def rulesets(self) -> RulesetsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class GetReleaseExecutableResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetReleaseExecutableResponse: ...

@typing.type_check_only
class ListReleasesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListReleasesResponse: ...

@typing.type_check_only
class ListRulesetsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListRulesetsResponse: ...

@typing.type_check_only
class ReleaseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Release: ...

@typing.type_check_only
class RulesetHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Ruleset: ...

@typing.type_check_only
class TestRulesetResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TestRulesetResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class ContactcenterinsightsResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class ConversationsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class AnalysesResource(googleapiclient.discovery.Resource):
                    def create(
                        self,
                        *,
                        parent: str,
                        body: GoogleCloudContactcenterinsightsV1Analysis = ...,
                        **kwargs: typing.Any
                    ) -> GoogleLongrunningOperationHttpRequest: ...
                    def delete(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> GoogleProtobufEmptyHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> GoogleCloudContactcenterinsightsV1AnalysisHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        filter: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudContactcenterinsightsV1ListAnalysesResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: GoogleCloudContactcenterinsightsV1ListAnalysesResponseHttpRequest,
                        previous_response: GoogleCloudContactcenterinsightsV1ListAnalysesResponse,
                    ) -> GoogleCloudContactcenterinsightsV1ListAnalysesResponseHttpRequest | None: ...

                def calculateStats(
                    self, *, location: str, filter: str = ..., **kwargs: typing.Any
                ) -> GoogleCloudContactcenterinsightsV1CalculateStatsResponseHttpRequest: ...
                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudContactcenterinsightsV1Conversation = ...,
                    conversationId: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudContactcenterinsightsV1ConversationHttpRequest: ...
                def delete(
                    self, *, name: str, force: bool = ..., **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self,
                    *,
                    name: str,
                    view: typing_extensions.Literal[
                        "CONVERSATION_VIEW_UNSPECIFIED", "FULL", "BASIC"
                    ] = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudContactcenterinsightsV1ConversationHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    view: typing_extensions.Literal[
                        "CONVERSATION_VIEW_UNSPECIFIED", "FULL", "BASIC"
                    ] = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudContactcenterinsightsV1ListConversationsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudContactcenterinsightsV1ListConversationsResponseHttpRequest,
                    previous_response: GoogleCloudContactcenterinsightsV1ListConversationsResponse,
                ) -> GoogleCloudContactcenterinsightsV1ListConversationsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudContactcenterinsightsV1Conversation = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudContactcenterinsightsV1ConversationHttpRequest: ...
                def analyses(self) -> AnalysesResource: ...

            @typing.type_check_only
            class InsightsdataResource(googleapiclient.discovery.Resource):
                def export(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudContactcenterinsightsV1ExportInsightsDataRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...

            @typing.type_check_only
            class IssueModelsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class IssuesResource(googleapiclient.discovery.Resource):
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> GoogleCloudContactcenterinsightsV1IssueHttpRequest: ...
                    def list(
                        self, *, parent: str, **kwargs: typing.Any
                    ) -> GoogleCloudContactcenterinsightsV1ListIssuesResponseHttpRequest: ...
                    def patch(
                        self,
                        *,
                        name: str,
                        body: GoogleCloudContactcenterinsightsV1Issue = ...,
                        updateMask: str = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudContactcenterinsightsV1IssueHttpRequest: ...

                def calculateIssueModelStats(
                    self, *, issueModel: str, **kwargs: typing.Any
                ) -> GoogleCloudContactcenterinsightsV1CalculateIssueModelStatsResponseHttpRequest: ...
                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudContactcenterinsightsV1IssueModel = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def deploy(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudContactcenterinsightsV1DeployIssueModelRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudContactcenterinsightsV1IssueModelHttpRequest: ...
                def list(
                    self, *, parent: str, **kwargs: typing.Any
                ) -> GoogleCloudContactcenterinsightsV1ListIssueModelsResponseHttpRequest: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudContactcenterinsightsV1IssueModel = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudContactcenterinsightsV1IssueModelHttpRequest: ...
                def undeploy(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudContactcenterinsightsV1UndeployIssueModelRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def issues(self) -> IssuesResource: ...

            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def cancel(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def list(
                    self,
                    *,
                    name: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningListOperationsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleLongrunningListOperationsResponseHttpRequest,
                    previous_response: GoogleLongrunningListOperationsResponse,
                ) -> GoogleLongrunningListOperationsResponseHttpRequest | None: ...

            @typing.type_check_only
            class PhraseMatchersResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudContactcenterinsightsV1PhraseMatcher = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudContactcenterinsightsV1PhraseMatcherHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudContactcenterinsightsV1PhraseMatcherHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudContactcenterinsightsV1ListPhraseMatchersResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudContactcenterinsightsV1ListPhraseMatchersResponseHttpRequest,
                    previous_response: GoogleCloudContactcenterinsightsV1ListPhraseMatchersResponse,
                ) -> GoogleCloudContactcenterinsightsV1ListPhraseMatchersResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudContactcenterinsightsV1PhraseMatcher = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudContactcenterinsightsV1PhraseMatcherHttpRequest: ...

            @typing.type_check_only
            class ViewsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudContactcenterinsightsV1View = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudContactcenterinsightsV1ViewHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudContactcenterinsightsV1ViewHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudContactcenterinsightsV1ListViewsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudContactcenterinsightsV1ListViewsResponseHttpRequest,
                    previous_response: GoogleCloudContactcenterinsightsV1ListViewsResponse,
                ) -> GoogleCloudContactcenterinsightsV1ListViewsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudContactcenterinsightsV1View = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudContactcenterinsightsV1ViewHttpRequest: ...

            def getSettings(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleCloudContactcenterinsightsV1SettingsHttpRequest: ...
            def updateSettings(
                self,
                *,
                name: str,
                body: GoogleCloudContactcenterinsightsV1Settings = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudContactcenterinsightsV1SettingsHttpRequest: ...
            def conversations(self) -> ConversationsResource: ...
            def insightsdata(self) -> InsightsdataResource: ...
            def issueModels(self) -> IssueModelsResource: ...
            def operations(self) -> OperationsResource: ...
            def phraseMatchers(self) -> PhraseMatchersResource: ...
            def views(self) -> ViewsResource: ...

        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1AnalysisHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudContactcenterinsightsV1Analysis: ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1CalculateIssueModelStatsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudContactcenterinsightsV1CalculateIssueModelStatsResponse: ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1CalculateStatsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudContactcenterinsightsV1CalculateStatsResponse: ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ConversationHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudContactcenterinsightsV1Conversation: ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1IssueHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudContactcenterinsightsV1Issue: ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1IssueModelHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudContactcenterinsightsV1IssueModel: ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ListAnalysesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudContactcenterinsightsV1ListAnalysesResponse: ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ListConversationsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudContactcenterinsightsV1ListConversationsResponse: ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ListIssueModelsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudContactcenterinsightsV1ListIssueModelsResponse: ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ListIssuesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudContactcenterinsightsV1ListIssuesResponse: ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ListPhraseMatchersResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudContactcenterinsightsV1ListPhraseMatchersResponse: ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ListViewsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudContactcenterinsightsV1ListViewsResponse: ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1PhraseMatcherHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudContactcenterinsightsV1PhraseMatcher: ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1SettingsHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudContactcenterinsightsV1Settings: ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ViewHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudContactcenterinsightsV1View: ...

@typing.type_check_only
class GoogleLongrunningListOperationsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunningListOperationsResponse: ...

@typing.type_check_only
class GoogleLongrunningOperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunningOperation: ...

@typing.type_check_only
class GoogleProtobufEmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleProtobufEmpty: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class ClassroomResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class CoursesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AliasesResource(googleapiclient.discovery.Resource):
            def create(
                self, *, courseId: str, body: CourseAlias = ..., **kwargs: typing.Any
            ) -> CourseAliasHttpRequest: ...
            def delete(
                self, *, courseId: str, alias: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def list(
                self,
                *,
                courseId: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListCourseAliasesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListCourseAliasesResponseHttpRequest,
                previous_response: ListCourseAliasesResponse,
            ) -> ListCourseAliasesResponseHttpRequest | None: ...

        @typing.type_check_only
        class AnnouncementsResource(googleapiclient.discovery.Resource):
            def create(
                self, *, courseId: str, body: Announcement = ..., **kwargs: typing.Any
            ) -> AnnouncementHttpRequest: ...
            def delete(
                self, *, courseId: str, id: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, courseId: str, id: str, **kwargs: typing.Any
            ) -> AnnouncementHttpRequest: ...
            def list(
                self,
                *,
                courseId: str,
                announcementStates: typing_extensions.Literal[
                    "ANNOUNCEMENT_STATE_UNSPECIFIED", "PUBLISHED", "DRAFT", "DELETED"
                ]
                | _list[
                    typing_extensions.Literal[
                        "ANNOUNCEMENT_STATE_UNSPECIFIED",
                        "PUBLISHED",
                        "DRAFT",
                        "DELETED",
                    ]
                ] = ...,
                orderBy: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListAnnouncementsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListAnnouncementsResponseHttpRequest,
                previous_response: ListAnnouncementsResponse,
            ) -> ListAnnouncementsResponseHttpRequest | None: ...
            def modifyAssignees(
                self,
                *,
                courseId: str,
                id: str,
                body: ModifyAnnouncementAssigneesRequest = ...,
                **kwargs: typing.Any
            ) -> AnnouncementHttpRequest: ...
            def patch(
                self,
                *,
                courseId: str,
                id: str,
                body: Announcement = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> AnnouncementHttpRequest: ...

        @typing.type_check_only
        class CourseWorkResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class StudentSubmissionsResource(googleapiclient.discovery.Resource):
                def get(
                    self,
                    *,
                    courseId: str,
                    courseWorkId: str,
                    id: str,
                    **kwargs: typing.Any
                ) -> StudentSubmissionHttpRequest: ...
                def list(
                    self,
                    *,
                    courseId: str,
                    courseWorkId: str,
                    late: typing_extensions.Literal[
                        "LATE_VALUES_UNSPECIFIED", "LATE_ONLY", "NOT_LATE_ONLY"
                    ] = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    states: typing_extensions.Literal[
                        "SUBMISSION_STATE_UNSPECIFIED",
                        "NEW",
                        "CREATED",
                        "TURNED_IN",
                        "RETURNED",
                        "RECLAIMED_BY_STUDENT",
                    ]
                    | _list[
                        typing_extensions.Literal[
                            "SUBMISSION_STATE_UNSPECIFIED",
                            "NEW",
                            "CREATED",
                            "TURNED_IN",
                            "RETURNED",
                            "RECLAIMED_BY_STUDENT",
                        ]
                    ] = ...,
                    userId: str = ...,
                    **kwargs: typing.Any
                ) -> ListStudentSubmissionsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListStudentSubmissionsResponseHttpRequest,
                    previous_response: ListStudentSubmissionsResponse,
                ) -> ListStudentSubmissionsResponseHttpRequest | None: ...
                def modifyAttachments(
                    self,
                    *,
                    courseId: str,
                    courseWorkId: str,
                    id: str,
                    body: ModifyAttachmentsRequest = ...,
                    **kwargs: typing.Any
                ) -> StudentSubmissionHttpRequest: ...
                def patch(
                    self,
                    *,
                    courseId: str,
                    courseWorkId: str,
                    id: str,
                    body: StudentSubmission = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> StudentSubmissionHttpRequest: ...
                def reclaim(
                    self,
                    *,
                    courseId: str,
                    courseWorkId: str,
                    id: str,
                    body: ReclaimStudentSubmissionRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def return_(
                    self,
                    *,
                    courseId: str,
                    courseWorkId: str,
                    id: str,
                    body: ReturnStudentSubmissionRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def turnIn(
                    self,
                    *,
                    courseId: str,
                    courseWorkId: str,
                    id: str,
                    body: TurnInStudentSubmissionRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...

            def create(
                self, *, courseId: str, body: CourseWork = ..., **kwargs: typing.Any
            ) -> CourseWorkHttpRequest: ...
            def delete(
                self, *, courseId: str, id: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, courseId: str, id: str, **kwargs: typing.Any
            ) -> CourseWorkHttpRequest: ...
            def list(
                self,
                *,
                courseId: str,
                courseWorkStates: typing_extensions.Literal[
                    "COURSE_WORK_STATE_UNSPECIFIED", "PUBLISHED", "DRAFT", "DELETED"
                ]
                | _list[
                    typing_extensions.Literal[
                        "COURSE_WORK_STATE_UNSPECIFIED", "PUBLISHED", "DRAFT", "DELETED"
                    ]
                ] = ...,
                orderBy: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListCourseWorkResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListCourseWorkResponseHttpRequest,
                previous_response: ListCourseWorkResponse,
            ) -> ListCourseWorkResponseHttpRequest | None: ...
            def modifyAssignees(
                self,
                *,
                courseId: str,
                id: str,
                body: ModifyCourseWorkAssigneesRequest = ...,
                **kwargs: typing.Any
            ) -> CourseWorkHttpRequest: ...
            def patch(
                self,
                *,
                courseId: str,
                id: str,
                body: CourseWork = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> CourseWorkHttpRequest: ...
            def studentSubmissions(self) -> StudentSubmissionsResource: ...

        @typing.type_check_only
        class CourseWorkMaterialsResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                courseId: str,
                body: CourseWorkMaterial = ...,
                **kwargs: typing.Any
            ) -> CourseWorkMaterialHttpRequest: ...
            def delete(
                self, *, courseId: str, id: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, courseId: str, id: str, **kwargs: typing.Any
            ) -> CourseWorkMaterialHttpRequest: ...
            def list(
                self,
                *,
                courseId: str,
                courseWorkMaterialStates: typing_extensions.Literal[
                    "COURSEWORK_MATERIAL_STATE_UNSPECIFIED",
                    "PUBLISHED",
                    "DRAFT",
                    "DELETED",
                ]
                | _list[
                    typing_extensions.Literal[
                        "COURSEWORK_MATERIAL_STATE_UNSPECIFIED",
                        "PUBLISHED",
                        "DRAFT",
                        "DELETED",
                    ]
                ] = ...,
                materialDriveId: str = ...,
                materialLink: str = ...,
                orderBy: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListCourseWorkMaterialResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListCourseWorkMaterialResponseHttpRequest,
                previous_response: ListCourseWorkMaterialResponse,
            ) -> ListCourseWorkMaterialResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                courseId: str,
                id: str,
                body: CourseWorkMaterial = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> CourseWorkMaterialHttpRequest: ...

        @typing.type_check_only
        class StudentsResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                courseId: str,
                body: Student = ...,
                enrollmentCode: str = ...,
                **kwargs: typing.Any
            ) -> StudentHttpRequest: ...
            def delete(
                self, *, courseId: str, userId: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, courseId: str, userId: str, **kwargs: typing.Any
            ) -> StudentHttpRequest: ...
            def list(
                self,
                *,
                courseId: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListStudentsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListStudentsResponseHttpRequest,
                previous_response: ListStudentsResponse,
            ) -> ListStudentsResponseHttpRequest | None: ...

        @typing.type_check_only
        class TeachersResource(googleapiclient.discovery.Resource):
            def create(
                self, *, courseId: str, body: Teacher = ..., **kwargs: typing.Any
            ) -> TeacherHttpRequest: ...
            def delete(
                self, *, courseId: str, userId: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, courseId: str, userId: str, **kwargs: typing.Any
            ) -> TeacherHttpRequest: ...
            def list(
                self,
                *,
                courseId: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListTeachersResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListTeachersResponseHttpRequest,
                previous_response: ListTeachersResponse,
            ) -> ListTeachersResponseHttpRequest | None: ...

        @typing.type_check_only
        class TopicsResource(googleapiclient.discovery.Resource):
            def create(
                self, *, courseId: str, body: Topic = ..., **kwargs: typing.Any
            ) -> TopicHttpRequest: ...
            def delete(
                self, *, courseId: str, id: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, courseId: str, id: str, **kwargs: typing.Any
            ) -> TopicHttpRequest: ...
            def list(
                self,
                *,
                courseId: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListTopicResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListTopicResponseHttpRequest,
                previous_response: ListTopicResponse,
            ) -> ListTopicResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                courseId: str,
                id: str,
                body: Topic = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> TopicHttpRequest: ...

        def create(
            self, *, body: Course = ..., **kwargs: typing.Any
        ) -> CourseHttpRequest: ...
        def delete(self, *, id: str, **kwargs: typing.Any) -> EmptyHttpRequest: ...
        def get(self, *, id: str, **kwargs: typing.Any) -> CourseHttpRequest: ...
        def list(
            self,
            *,
            courseStates: typing_extensions.Literal[
                "COURSE_STATE_UNSPECIFIED",
                "ACTIVE",
                "ARCHIVED",
                "PROVISIONED",
                "DECLINED",
                "SUSPENDED",
            ]
            | _list[
                typing_extensions.Literal[
                    "COURSE_STATE_UNSPECIFIED",
                    "ACTIVE",
                    "ARCHIVED",
                    "PROVISIONED",
                    "DECLINED",
                    "SUSPENDED",
                ]
            ] = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            studentId: str = ...,
            teacherId: str = ...,
            **kwargs: typing.Any
        ) -> ListCoursesResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListCoursesResponseHttpRequest,
            previous_response: ListCoursesResponse,
        ) -> ListCoursesResponseHttpRequest | None: ...
        def patch(
            self,
            *,
            id: str,
            body: Course = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> CourseHttpRequest: ...
        def update(
            self, *, id: str, body: Course = ..., **kwargs: typing.Any
        ) -> CourseHttpRequest: ...
        def aliases(self) -> AliasesResource: ...
        def announcements(self) -> AnnouncementsResource: ...
        def courseWork(self) -> CourseWorkResource: ...
        def courseWorkMaterials(self) -> CourseWorkMaterialsResource: ...
        def students(self) -> StudentsResource: ...
        def teachers(self) -> TeachersResource: ...
        def topics(self) -> TopicsResource: ...

    @typing.type_check_only
    class InvitationsResource(googleapiclient.discovery.Resource):
        def accept(self, *, id: str, **kwargs: typing.Any) -> EmptyHttpRequest: ...
        def create(
            self, *, body: Invitation = ..., **kwargs: typing.Any
        ) -> InvitationHttpRequest: ...
        def delete(self, *, id: str, **kwargs: typing.Any) -> EmptyHttpRequest: ...
        def get(self, *, id: str, **kwargs: typing.Any) -> InvitationHttpRequest: ...
        def list(
            self,
            *,
            courseId: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            userId: str = ...,
            **kwargs: typing.Any
        ) -> ListInvitationsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListInvitationsResponseHttpRequest,
            previous_response: ListInvitationsResponse,
        ) -> ListInvitationsResponseHttpRequest | None: ...

    @typing.type_check_only
    class RegistrationsResource(googleapiclient.discovery.Resource):
        def create(
            self, *, body: Registration = ..., **kwargs: typing.Any
        ) -> RegistrationHttpRequest: ...
        def delete(
            self, *, registrationId: str, **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...

    @typing.type_check_only
    class UserProfilesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class GuardianInvitationsResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                studentId: str,
                body: GuardianInvitation = ...,
                **kwargs: typing.Any
            ) -> GuardianInvitationHttpRequest: ...
            def get(
                self, *, studentId: str, invitationId: str, **kwargs: typing.Any
            ) -> GuardianInvitationHttpRequest: ...
            def list(
                self,
                *,
                studentId: str,
                invitedEmailAddress: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                states: typing_extensions.Literal[
                    "GUARDIAN_INVITATION_STATE_UNSPECIFIED", "PENDING", "COMPLETE"
                ]
                | _list[
                    typing_extensions.Literal[
                        "GUARDIAN_INVITATION_STATE_UNSPECIFIED", "PENDING", "COMPLETE"
                    ]
                ] = ...,
                **kwargs: typing.Any
            ) -> ListGuardianInvitationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListGuardianInvitationsResponseHttpRequest,
                previous_response: ListGuardianInvitationsResponse,
            ) -> ListGuardianInvitationsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                studentId: str,
                invitationId: str,
                body: GuardianInvitation = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> GuardianInvitationHttpRequest: ...

        @typing.type_check_only
        class GuardiansResource(googleapiclient.discovery.Resource):
            def delete(
                self, *, studentId: str, guardianId: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, studentId: str, guardianId: str, **kwargs: typing.Any
            ) -> GuardianHttpRequest: ...
            def list(
                self,
                *,
                studentId: str,
                invitedEmailAddress: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListGuardiansResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListGuardiansResponseHttpRequest,
                previous_response: ListGuardiansResponse,
            ) -> ListGuardiansResponseHttpRequest | None: ...

        def get(
            self, *, userId: str, **kwargs: typing.Any
        ) -> UserProfileHttpRequest: ...
        def guardianInvitations(self) -> GuardianInvitationsResource: ...
        def guardians(self) -> GuardiansResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def courses(self) -> CoursesResource: ...
    def invitations(self) -> InvitationsResource: ...
    def registrations(self) -> RegistrationsResource: ...
    def userProfiles(self) -> UserProfilesResource: ...

@typing.type_check_only
class AnnouncementHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Announcement: ...

@typing.type_check_only
class CourseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Course: ...

@typing.type_check_only
class CourseAliasHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CourseAlias: ...

@typing.type_check_only
class CourseWorkHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CourseWork: ...

@typing.type_check_only
class CourseWorkMaterialHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CourseWorkMaterial: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class GuardianHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Guardian: ...

@typing.type_check_only
class GuardianInvitationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GuardianInvitation: ...

@typing.type_check_only
class InvitationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Invitation: ...

@typing.type_check_only
class ListAnnouncementsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAnnouncementsResponse: ...

@typing.type_check_only
class ListCourseAliasesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCourseAliasesResponse: ...

@typing.type_check_only
class ListCourseWorkMaterialResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCourseWorkMaterialResponse: ...

@typing.type_check_only
class ListCourseWorkResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCourseWorkResponse: ...

@typing.type_check_only
class ListCoursesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCoursesResponse: ...

@typing.type_check_only
class ListGuardianInvitationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListGuardianInvitationsResponse: ...

@typing.type_check_only
class ListGuardiansResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListGuardiansResponse: ...

@typing.type_check_only
class ListInvitationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListInvitationsResponse: ...

@typing.type_check_only
class ListStudentSubmissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListStudentSubmissionsResponse: ...

@typing.type_check_only
class ListStudentsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListStudentsResponse: ...

@typing.type_check_only
class ListTeachersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListTeachersResponse: ...

@typing.type_check_only
class ListTopicResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListTopicResponse: ...

@typing.type_check_only
class RegistrationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Registration: ...

@typing.type_check_only
class StudentHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Student: ...

@typing.type_check_only
class StudentSubmissionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> StudentSubmission: ...

@typing.type_check_only
class TeacherHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Teacher: ...

@typing.type_check_only
class TopicHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Topic: ...

@typing.type_check_only
class UserProfileHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> UserProfile: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AdmissionRule(typing_extensions.TypedDict, total=False):
    enforcementMode: typing_extensions.Literal[
        "ENFORCEMENT_MODE_UNSPECIFIED",
        "ENFORCED_BLOCK_AND_AUDIT_LOG",
        "DRYRUN_AUDIT_LOG_ONLY",
    ]
    evaluationMode: typing_extensions.Literal[
        "EVALUATION_MODE_UNSPECIFIED",
        "ALWAYS_ALLOW",
        "REQUIRE_ATTESTATION",
        "ALWAYS_DENY",
    ]
    requireAttestationsBy: _list[str]

@typing.type_check_only
class AdmissionWhitelistPattern(typing_extensions.TypedDict, total=False):
    namePattern: str

@typing.type_check_only
class AttestationOccurrence(typing_extensions.TypedDict, total=False):
    jwts: _list[Jwt]
    serializedPayload: str
    signatures: _list[Signature]

@typing.type_check_only
class Attestor(typing_extensions.TypedDict, total=False):
    description: str
    etag: str
    name: str
    updateTime: str
    userOwnedDrydockNote: UserOwnedDrydockNote

@typing.type_check_only
class AttestorPublicKey(typing_extensions.TypedDict, total=False):
    asciiArmoredPgpPublicKey: str
    comment: str
    id: str
    pkixPublicKey: PkixPublicKey

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class IamPolicy(typing_extensions.TypedDict, total=False):
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class Jwt(typing_extensions.TypedDict, total=False):
    compactJwt: str

@typing.type_check_only
class ListAttestorsResponse(typing_extensions.TypedDict, total=False):
    attestors: _list[Attestor]
    nextPageToken: str

@typing.type_check_only
class PkixPublicKey(typing_extensions.TypedDict, total=False):
    publicKeyPem: str
    signatureAlgorithm: typing_extensions.Literal[
        "SIGNATURE_ALGORITHM_UNSPECIFIED",
        "RSA_PSS_2048_SHA256",
        "RSA_SIGN_PSS_2048_SHA256",
        "RSA_PSS_3072_SHA256",
        "RSA_SIGN_PSS_3072_SHA256",
        "RSA_PSS_4096_SHA256",
        "RSA_SIGN_PSS_4096_SHA256",
        "RSA_PSS_4096_SHA512",
        "RSA_SIGN_PSS_4096_SHA512",
        "RSA_SIGN_PKCS1_2048_SHA256",
        "RSA_SIGN_PKCS1_3072_SHA256",
        "RSA_SIGN_PKCS1_4096_SHA256",
        "RSA_SIGN_PKCS1_4096_SHA512",
        "ECDSA_P256_SHA256",
        "EC_SIGN_P256_SHA256",
        "ECDSA_P384_SHA384",
        "EC_SIGN_P384_SHA384",
        "ECDSA_P521_SHA512",
        "EC_SIGN_P521_SHA512",
    ]

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    admissionWhitelistPatterns: _list[AdmissionWhitelistPattern]
    clusterAdmissionRules: dict[str, typing.Any]
    defaultAdmissionRule: AdmissionRule
    description: str
    etag: str
    globalPolicyEvaluationMode: typing_extensions.Literal[
        "GLOBAL_POLICY_EVALUATION_MODE_UNSPECIFIED", "ENABLE", "DISABLE"
    ]
    istioServiceIdentityAdmissionRules: dict[str, typing.Any]
    kubernetesNamespaceAdmissionRules: dict[str, typing.Any]
    kubernetesServiceAccountAdmissionRules: dict[str, typing.Any]
    name: str
    updateTime: str

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: IamPolicy

@typing.type_check_only
class Signature(typing_extensions.TypedDict, total=False):
    publicKeyId: str
    signature: str

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class UserOwnedDrydockNote(typing_extensions.TypedDict, total=False):
    delegationServiceAccountEmail: str
    noteReference: str
    publicKeys: _list[AttestorPublicKey]

@typing.type_check_only
class ValidateAttestationOccurrenceRequest(typing_extensions.TypedDict, total=False):
    attestation: AttestationOccurrence
    occurrenceNote: str
    occurrenceResourceUri: str

@typing.type_check_only
class ValidateAttestationOccurrenceResponse(typing_extensions.TypedDict, total=False):
    denialReason: str
    result: typing_extensions.Literal[
        "RESULT_UNSPECIFIED", "VERIFIED", "ATTESTATION_NOT_VERIFIABLE"
    ]
